@@ -5,7 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
-#  Copyright 2015-2021 Statnet Commons
+#  Copyright 2015-2022 Statnet Commons
 ################################################################################
 
 
@@ -65,9 +65,9 @@
 #' statistics and their variance: \describe{
 #' \item{"survey"}{Variance estimator returned by [survey::svymean()], appropriate to the design of the dataset.}
 #' \item{"asymptotic"}{Delta method, as derived by Krivitsky and
-#' Morris (2015), assuming the ego weights are sampled alongside the
+#' Morris (2017), assuming the ego weights are sampled alongside the
 #' egos.}\item{ (default)}{Delta method, as derived by Krivitsky and Morris
-#' (2015), assuming the ego weights are sampled alongside the egos.}
+#' (2017), assuming the ego weights are sampled alongside the egos.}
 #' \item{"bootstrap"}{Nonparametric bootstrap with bias correction,
 #' resampling egos, using \code{R} replications.}
 #' \item{"jackknife"}{Jackknife with bias correction.}
@@ -75,21 +75,24 @@
 #' fixed.} }
 #' 
 #' @param ignore.max.alters if `TRUE`, ignores any constraints on the
-#'   number of nominations.
+#'   number of nominations. Used to be `FALSE`, now `TRUE` in light of
+#'   the findings of Krivitsky et. al (2020).
 #' 
-#' @param ergm Control parameters for the \code{\link[ergm]{ergm}} call
-#' to fit the model, constructed by \code{\link[ergm]{control.ergm}}.
+#' @param ergm Control parameters for the \code{\link[ergm]{ergm}()} call
+#' to fit the model, constructed by \code{\link[ergm]{control.ergm}()}.
 #' @param \dots Not used at this time.
 #' @return A list with arguments as components.
 #' @author Pavel N. Krivitsky
-#' @seealso control.ergm
+#' @seealso \code{\link[ergm]{control.ergm}()}
 #' @references
 #' 
-#' * Pavel N. Krivitsky and Martina Morris (2017). "Inference for social network models from egocentrically sampled data, with application to understanding persistent racial disparities in HIV prevalence in the US." *Annals of Applied Statistics*, 11(1): 427–455. \doi{10.1214/16-AOAS1010}
+#' Pavel N. Krivitsky and Martina Morris (2017). "Inference for social network models from egocentrically sampled data, with application to understanding persistent racial disparities in HIV prevalence in the US." *Annals of Applied Statistics*, 11(1): 427–455. \doi{10.1214/16-AOAS1010}
 #'
-#' * Pavel N. Krivitsky, Martina Morris, and Michał Bojanowski (2019). "Inference for Exponential-Family Random Graph Models from Egocentrically-Sampled Data with Alter–Alter Relations." NIASRA Working Paper 08-19. \url{https://www.uow.edu.au/niasra/publications/}
+#' Pavel N. Krivitsky, Martina Morris, and Michał Bojanowski (2019). "Inference for Exponential-Family Random Graph Models from Egocentrically-Sampled Data with Alter–Alter Relations." NIASRA Working Paper 08-19. \url{https://www.uow.edu.au/niasra/publications/}
 #'
-#' * Pavel N. Krivitsky, Mark S. Handcock, and Martina Morris (2011). "Adjusting for
+#' Pavel N. Krivitsky, Michał Bojanowski, and Martina Morris (2020). "Impact of survey design on estimation of exponential-family random graph models from egocentrically-sampled data." *Social Networks*, to appear. \doi{10.1016/j.socnet.2020.10.001}
+#' 
+#' Pavel N. Krivitsky, Mark S. Handcock, and Martina Morris (2011). "Adjusting for
 #' Network Size and Composition Effects in Exponential-Family Random Graph
 #' Models." \emph{Statistical Methodology}, 8(4): 319–339. \doi{10.1016/j.stamet.2011.01.005}
 #'
@@ -102,7 +105,7 @@ control.ergm.ego <- function(
   stats.wt = c("data","ppop"),
   stats.est = c("survey","asymptotic", "bootstrap", "jackknife", "naive"),
   boot.R = 10000,
-  ignore.max.alters = FALSE,
+  ignore.max.alters = TRUE,
   ergm = control.ergm(),
   ...){
   old.controls <- list(ergm.control="ergm")
